@@ -59,12 +59,12 @@
 #define KEYDATA_PATH_SIZE   256
 #endif
 
-NAMESPACE_COMMONCPP
+namespace ost {
 
 class __EXPORT MemPager : private ucommon::memalloc
 {
 public:
-	inline MemPager(size_t pagesize = 4096) : ucommon::memalloc(pagesize) {};
+    inline MemPager(size_t pagesize = 4096) : ucommon::memalloc(pagesize) {}
 
 	inline void *alloc(size_t size)
 		{return _alloc(size);}
@@ -152,5 +152,5 @@ public:
     void setPointer(const char *id, void *data);
 };
 
-END_NAMESPACE
+} // namespace ost
 #endif
