@@ -82,16 +82,14 @@ extern "C" __EXPORT void cpr_memswap(void *mem1, void *mem2, size_t size);
  * @param size of object being constructed.
  * @return memory allocated from heap.
  */
-inline void *operator new(size_t size)
-    {return cpr_memalloc(size);}
+__EXPORT void *operator new(size_t size);
 
 /**
  * Our generic new array operator.  Uses our heap memory allocator.
  * @param size of memory needed for object array.
  * @return memory allocated from heap.
  */
-inline void *operator new[](size_t size)
-    {return cpr_memalloc(size);}
+__EXPORT void *operator new[](size_t size);
 #endif
 
 #ifndef _UCOMMON_EXTENDED_
@@ -103,8 +101,7 @@ inline void *operator new[](size_t size)
  * @param address where to place object array.
  * @return memory we placed object array.
  */
-inline void *operator new[](size_t size, caddr_t address)
-    {return cpr_memassign(size, address, size);}
+__EXPORT void *operator new[](size_t size, caddr_t address);
 
 /**
  * A placement new array operator where we know the allocated size.  We
@@ -115,8 +112,7 @@ inline void *operator new[](size_t size, caddr_t address)
  * @param known size of location we are placing array.
  * @return memory we placed object array.
  */
-inline void *operator new[](size_t size, caddr_t address, size_t known)
-    {return cpr_memassign(size, address, known);}
+__EXPORT void *operator new[](size_t size, caddr_t address, size_t known);
 #endif
 
 /**
@@ -128,8 +124,7 @@ inline void *operator new[](size_t size, caddr_t address, size_t known)
  * @param size of object.
  * @param extra heap space needed for data.
  */
-inline void *operator new(size_t size, size_t extra)
-    {return cpr_memalloc(size + extra);}
+__EXPORT void *operator new(size_t size, size_t extra);
 
 /**
  * A placement new operator where we assume the size of memory is good.
@@ -139,8 +134,7 @@ inline void *operator new(size_t size, size_t extra)
  * @param address where to place object.
  * @return memory we placed object.
  */
-inline void *operator new(size_t size, caddr_t address)
-    {return cpr_memassign(size, address, size);}
+__EXPORT void *operator new(size_t size, caddr_t address);
 
 /**
  * A placement new operator where we know the allocated size.  We
@@ -152,23 +146,28 @@ inline void *operator new(size_t size, caddr_t address)
  * @return memory we placed object.
  */
 
-inline void *operator new(size_t size, caddr_t address, size_t known)
-    {return cpr_memassign(size, address, known);}
+__EXPORT void *operator new(size_t size, caddr_t address, size_t known);
 
 #ifndef _UCOMMON_EXTENDED_
 /**
  * Delete an object from the heap.
  * @param object to delete.
  */
-inline void operator delete(void *object)
-    {free(object);}
+#if __cplusplus <= 199711L
+__EXPORT void operator delete(void *object);
+#else
+__EXPORT void operator delete(void *object) noexcept (true);
+#endif
 
 /**
  * Delete an array from the heap.  All array element destructors are called.
  * @param array to delete.
  */
-inline void operator delete[](void *array)
-    {free(array);}
+#if __cplusplus <= 199711L
+__EXPORT void operator delete[](void *array);
+#else
+__EXPORT void operator delete[](void *array) noexcept(true);
+#endif
 
 #ifdef  __GNUC__
 extern "C" __EXPORT void __cxa_pure_virtual(void);
