@@ -809,7 +809,7 @@ public:
      * type of socket created is based on the type we are connecting to.
      * @param address list to connect with.
      */
-    Socket(struct addrinfo *address);
+    Socket(const struct addrinfo *address);
 
     /**
      * Create an unbound socket of a specific type.
@@ -862,7 +862,7 @@ public:
      * @param value to test for.
      * @return true if at least that many bytes waiting in receive queue.
      */
-    bool is_pending(unsigned value) const;
+    bool is_pending(unsigned value);
 
     /**
      * Test if socket is connected.
